.. servalcat documentation master file, created by
   sphinx-quickstart on Fri Apr 22 07:49:31 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Servalcat - refinement and map calculation
==========================================

Servalcat (for **S**\ tructur\ **e** **r**\ efinement and **val**\ idation for **c**\ rystallography and single p\ **a**\ r\ **t**\ icle analysis) is a software package for atomic model refinement and map calculation.
We currently focus on cryo-EM single particle analysis (SPA).


Source code repository: https://github.com/keitaroyam/servalcat

.. note::

   If Servalcat is useful for your research, please cite:
   Yamashita, K., Palmer, C. M., Burnley, T., Murshudov, G. N. (2021) "Cryo-EM single particle structure refinement and map calculation using Servalcat" *Acta Cryst. D*\ **77**, 1282-1291 doi: `10.1107/S2059798321009475 <https://doi.org/10.1107/S2059798321009475>`_

Table of Contents
-----------------
.. toctree::
   :maxdepth: 2

   overview
   spa
   spa_examples/index
   commands
